Acknowledgements
-----------------
`neutcurve` is written by the `Bloom lab  <https://jbloomlab.org>`_.

See https://github.com/jbloomlab/neutcurve/graphs/contributors for the full list of contributors.

Please cite `Loes et al (2024) <https://doi.org/10.1128/jvi.00689-24>`_ if you use `neutcurve` in your scientific study.
